@@ -1,5 +1,9 @@
 import requests
-from py2http.service import mk_http_service, mk_routes_and_openapi_specs, run_http_service
+from py2http.service import (
+    mk_http_service,
+    mk_routes_and_openapi_specs,
+    run_http_service,
+)
 from http2py.py2request import mk_request_func_from_openapi_spec
 from py2http.util import ModuleNotFoundIgnore
 from py2http.util import conditional_logger, run_process
@@ -26,18 +30,23 @@ def client_funcs_from_openapi(openapi_spec, **h2p_configs):
 
     for (path, method), spec in e.paths_and_methods_items():
         yield mk_request_func_from_openapi_spec(
-            path, openapi_spec, method, **h2p_configs)
+            path, openapi_spec, method, **h2p_configs
+        )
 
 
 def get_client_funcs(funcs, p2h_configs=None, h2p_configs=None):
-    routes, openapi_spec = mk_routes_and_openapi_specs(funcs, p2h_configs or {})
+    routes, openapi_spec = mk_routes_and_openapi_specs(
+        funcs, **(p2h_configs or {})
+    )
     return list(client_funcs_from_openapi(openapi_spec, **(h2p_configs or {})))
 
 
 def p2h2p_app(funcs, p2h_configs=None, h2p_configs=None):
     app = mk_http_service(funcs, **(p2h_configs or {}))
     # w_funcs = list(_w_funcs(funcs, app.openapi_spec, **(h2p_configs or {})))
-    c_funcs = list(client_funcs_from_openapi(app.openapi_spec, **(h2p_configs or {})))
+    c_funcs = list(
+        client_funcs_from_openapi(app.openapi_spec, **(h2p_configs or {}))
+    )
     app.funcs = funcs
     app.c_funcs = c_funcs
     return app
@@ -51,9 +60,15 @@ def p2h2p_app(funcs, p2h_configs=None, h2p_configs=None):
 # equivalence tests ############################################
 
 
-def p2h2p_test(funcs, inputs_for_func=None, p2h_configs=None, h2p_configs=None,
-               check_signatures=False, wait_before_entering=2,
-               verbose=False):
+def p2h2p_test(
+    funcs,
+    inputs_for_func=None,
+    p2h_configs=None,
+    h2p_configs=None,
+    check_signatures=False,
+    wait_before_entering=2,
+    verbose=False,
+):
     """
 
     :param funcs: An iterable of callables
@@ -65,14 +80,18 @@ def p2h2p_test(funcs, inputs_for_func=None, p2h_configs=None, h2p_configs=None,
     :return:
     """
     clog = conditional_logger(verbose)
-    client_funcs = get_client_funcs(funcs, p2h_configs=p2h_configs, h2p_configs=h2p_configs)
-    with run_process(func=run_http_service,
-                     func_args=(funcs,),
-                     func_kwargs=dict({}, configs=p2h_configs),
-                     is_ready=wait_before_entering,
-                     verbose=verbose) as proc:
+    client_funcs = get_client_funcs(
+        funcs, p2h_configs=p2h_configs, h2p_configs=h2p_configs
+    )
+    with run_process(
+        func=run_http_service,
+        func_args=(funcs,),
+        func_kwargs=dict({}, configs=p2h_configs),
+        is_ready=wait_before_entering,
+        verbose=verbose,
+    ) as proc:
         for f, cf in zip(funcs, client_funcs):
-            clog(f"{signature(f)} -- {signature(cf)}")
+            clog(f'{signature(f)} -- {signature(cf)}')
             if check_signatures:
                 assert signature(f) == signature(cf)
             if isinstance(inputs_for_func, Iterable):
@@ -83,7 +102,7 @@ def p2h2p_test(funcs, inputs_for_func=None, p2h_configs=None, h2p_configs=None,
 
 
 dflt_port = '3030'
-dflt_root_url = "http://localhost"
+dflt_root_url = 'http://localhost'
 dflt_base_url = dflt_root_url + ':' + dflt_port
 
 
@@ -91,7 +110,9 @@ def example_test(base_url=dflt_base_url):
     add_result = requests.post(f'{base_url}/add', json={'a': 10, 'b': 5})
     assert str(add_result.json()) == '15'
 
-    multiply_result = requests.post(f'{base_url}/multiply', json={'multiplier': 6})
+    multiply_result = requests.post(
+        f'{base_url}/multiply', json={'multiplier': 6}
+    )
     assert str(multiply_result.json()) == '30'
 
     no_args_result = requests.post(f'{base_url}/no_args', json={})
@@ -108,6 +129,7 @@ def power(x, p=1):
         result = result * x if p > 0 else result / x
     return result
 
+
 def test_types(str='', int=0, float=0.0, list=[], dict={}, bool=True):
     pass
 
@@ -124,6 +146,4 @@ if __name__ == '__main__':
         power: zip([(10,), (5,)], [{'p': 1}, {'p': 2}]),
     }
 
-    p2h2p_test(funcs=funcs,
-               inputs_for_func=inputs_for_func,
-               verbose=True)
+    p2h2p_test(funcs=funcs, inputs_for_func=inputs_for_func, verbose=True)
